==> hbase-shaded-miscellaneous-2.1.0-sources.jar: org/apache/hbase/thirdparty/com/google/common/util/concurrent/package-info.java <==
/*
 * Copyright (C) 2007 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

/**
 * Concurrency utilities.
 *
 * <p>Commonly used types include {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.ListenableFuture} and
 * {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.Service}.
 *
 * <p>Commonly used utilities include {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.Futures},
 * {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.MoreExecutors}, and
 * {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder}.
 *
 * <p>This package is a part of the open-source <a href="http://github.org.apache.hbase.thirdparty.com.google/guava">Guava</a>
 * library.
 */
@CheckReturnValue
@ParametersAreNonnullByDefault
package org.apache.hbase.thirdparty.com.google.common.util.concurrent;

import javax.annotation.CheckReturnValue;
import javax.annotation.ParametersAreNonnullByDefault;

==> hbase-shaded-miscellaneous-2.2.0-sources.jar: org/apache/hbase/thirdparty/com/google/common/util/concurrent/package-info.java <==
/*
 * Copyright (C) 2007 The Guava Authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except
 * in compliance with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License
 * is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express
 * or implied. See the License for the specific language governing permissions and limitations under
 * the License.
 */

/**
 * Concurrency utilities.
 *
 * <p>Commonly used types include {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.ListenableFuture} and
 * {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.Service}.
 *
 * <p>Commonly used utilities include {@link org.apache.hbase.thirdparty.com.google.common.util.concurrent.Futures}, {@link
 * org.apache.hbase.thirdparty.com.google.common.util.concurrent.MoreExecutors}, and {@link
 * org.apache.hbase.thirdparty.com.google.common.util.concurrent.ThreadFactoryBuilder}.
 *
 * <p>This package is a part of the open-source <a href="http://github.org.apache.hbase.thirdparty.com.google/guava">Guava</a>
 * library.
 */
@CheckReturnValue
@ParametersAreNonnullByDefault
package org.apache.hbase.thirdparty.com.google.common.util.concurrent;

import org.apache.hbase.thirdparty.com.google.errorprone.annotations.CheckReturnValue;
import javax.annotation.ParametersAreNonnullByDefault;
